@@ -4,4 +4,4 @@ from appconf import AppConf
 
 class PodcastingAppConf(AppConf):
     PAGINATE_BY = 10
-    FEED_ENTRIES = 10
+    FEED_ENTRIES = None
